@@ -13,7 +13,7 @@ import requests
 from time import sleep
 from datetime import datetime
 from typing import Optional, Dict, List, Union
-from tqdm.notebook import trange, tqdm
+from tqdm.auto import tqdm
 from requests.auth import AuthBase
 from sumatra.auth import SDKKeyAuth, CognitoJwtAuth
 from sumatra.config import CONFIG
@@ -1393,19 +1393,6 @@ class Materialization:
 
         return ret["data"]["materialization"]
 
-    def _wait_for_processing(self):
-        RETRIES = 180
-        DELAY = 5.0
-        retry_count = 0
-        while retry_count < RETRIES:
-            if self.status != "processing":
-                return
-            time.sleep(DELAY)
-            retry_count += 1
-        if self.status == "processing":
-            raise Exception(f"Timed out after {DELAY * RETRIES} seconds")
-
-    @property
     def status(self) -> str:
         """
         Current status of the job. One of {'processing', 'materialized', 'error'}
@@ -1420,9 +1407,10 @@ class Materialization:
         Returns:
             Materialization status
         """
+
         self._mtr = self._get_materialization()
-        if self._mtr["state"] != "processing":
-            return self._mtr["state"]
+        if self._mtr["state"] not in ["processing", "materialized"]:
+            raise Exception(f"Error in {self}: {self._mtr['state']}")
 
         while self._mtr["jobsSubmitted"] == 0 and self._mtr["state"] == "processing":
             sleep(0.5)
@@ -1449,7 +1437,6 @@ class Materialization:
 
         return self._mtr["state"]
 
-    @property
     def progress(self) -> str:
         """
         Current progress of subjobs: X of Y jobs completed.
@@ -1508,7 +1495,7 @@ class Materialization:
         """
         S3 bucket path where results are stored.
         """
-        self._wait_for_processing()
+        self.wait()
         return self._mtr["path"]
 
     def get_events(self, event_type: str, features: List[str] = []) -> pd.DataFrame:
@@ -1526,7 +1513,7 @@ class Materialization:
         # if event_type not in self.event_types:
         #    raise Exception(f"Event type '{event_type}' not found.")
 
-        self._wait_for_processing()
+        self.wait()
         session = self._client._get_session()
 
         path = f"{self.path}/events/event_type={event_type}/"
@@ -1565,7 +1552,7 @@ class Materialization:
         # if event_type not in self.event_types:
         #    raise Exception(f"Event type '{event_type}' not found.")
 
-        self._wait_for_processing()
+        self.wait()
         session = self._client._get_session()
 
         path = f"{self.path}/errors/event_type={event_type}/"
